internal

package
v0.0.0-...-616e1d4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanLine

func CleanLine(line *string, keepCapitalisation bool)

func Log

func Log(a ...any)

func ReadCorpus

func ReadCorpus(filepath string, readLine func(string)) error

Types

This section is empty.

Directories

Path Synopsis
Package commands lists all the commands available for the [cli] part of the program.
Package commands lists all the commands available for the [cli] part of the program.
Package repl is responsible for defining an interface for all the [commands], and is responsible for generating output for any input provided.
Package repl is responsible for defining an interface for all the [commands], and is responsible for generating output for any input provided.
Package tui is responsible for providing BubbleTea models and views which are used by [cli].
Package tui is responsible for providing BubbleTea models and views which are used by [cli].

Jump to